define("libs/browser/fs",function(require,exports,module){
"use strict";

var _util = _interopRequireDefault(require("libs/ni/util"));

var _fs = _interopRequireDefault(require("libs/ni/fs"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/****************** 导出 ******************/

/****************** 本地 ******************/

/**
 * @description 浏览器文件处理类
 */
var Browser =
/*#__PURE__*/
function () {
  _createClass(Browser, [{
    key: "init",
    value: function init(callback, errorCallback) {
      var _this = this;

      if (!_this.iDB) {
        _this.db = {};
        return callback && setTimeout(callback, 0);
      }

      try {
        var request = _this.iDB.open(_this.dbName, 1);

        request.onupgradeneeded = function (e) {
          // 创建table
          e.currentTarget.result.createObjectStore(_this.tabName, {
            autoIncrement: false
          });
        };

        request.onsuccess = function (e) {
          _this.db = e.currentTarget.result;
          callback && callback();
        };

        request.onerror = errorCallback;
      } catch (e) {
        _this.iDB = undefined;
        _this.db = {};
        return callback && setTimeout(callback, 0);
      }
    }
  }]);

  function Browser(cfg, callback) {
    _classCallCheck(this, Browser);

    this.iDB = void 0;
    this.dbName = void 0;
    this.tabName = void 0;
    this.depend = void 0;
    this.db = void 0;
    this.except = [];
    this.isReady = false;

    var _this = this;

    _this.dbName = cfg.name;
    _this.tabName = cfg.name;
    _this.iDB = self.indexedDB || self.webkitIndexedDB || self.mozIndexedDB || self.OIndexedDB || self.msIndexedDB;

    _this.init(function () {
      setTimeout(function () {
        _this.read("_.depend", function (err, data) {
          _this.depend = err || !data ? {} : JSON.parse(data);
          callback && callback();
        });
      }, 0);
    }, function (err) {
      console.log(err);
    });
  }

  _createClass(Browser, [{
    key: "isLocal",
    value: function isLocal(path, sign) {
      if (_fs.default.from == "app") {
        return false;
      } else {
        return this.depend[path] == sign;
      }
    }
    /**
     * @description 读取数据
     * @example
     */

  }, {
    key: "read",
    value: function read(path, callback) {
      var _this = this;

      if (!_this.iDB) {
        return setTimeout(function () {
          callback(null, _this.db[path]);
        }, 0);
      }

      var request = this.db.transaction(_this.tabName, "readonly").objectStore(_this.tabName).get(path);

      request.onsuccess = function (e) {
        callback(null, e.target.result);
      };

      request.onerror = function (error) {
        callback(error);
      };
    }
  }, {
    key: "write",

    /**
     * @description 写入数据，如果键名存在则替换
     * @example
     */
    value: function write(path, data, callback, notWriteDepend) {
      var _this2 = this;

      if (!this.iDB) {
        this.db[path] = data;
        return callback && setTimeout(callback, 0);
      }

      var tx = this.db.transaction(this.tabName, "readwrite");
      tx.objectStore(this.tabName).put(data, path);

      tx.oncomplete = function () {
        if (!notWriteDepend) {
          _this2.depend[path] = _fs.default.depend.all[path].sign;

          _fs.default.writeCacheDpend();
        }
      };

      tx.onerror = function (error) {// callback(error);
      };

      setTimeout(function () {
        callback(null, path);
      }, 0);
    }
  }, {
    key: "createImg",

    /**
     * @description 创建可用图片url
     * @param path 
     * @param data 
     */
    value: function createImg(path, data) {
      var suf = _util.default.fileSuffix(path);

      var blob = new Blob([data], {
        type: _fs.default.BlobType[suf]
      });
      var url = URL.createObjectURL(blob);
      return url;
    }
    /**
     * @description 删除数据
     * @example
     */

  }, {
    key: "delete",
    value: function _delete(path, callback) {
      if (!this.iDB) {
        delete this.db[path];
        return callback && setTimeout(callback, 0);
      }

      var tx = this.db.transaction(this.tabName, "readwrite");
      tx.objectStore(this.tabName).delete(path);

      tx.oncomplete = function () {
        callback();
      };

      tx.onerror = function (error) {
        callback(error);
      };
    }
  }, {
    key: "writeDepend",

    /**
     * @description 写入缓存depend
     * @param callback 
     */
    value: function writeDepend(callback) {
      this.write("_.depend", JSON.stringify(this.depend), function (err) {
        callback(err);
      }, true);
    }
    /**
        * @description 添加字体
        * @param path 
        */

  }, {
    key: "addFont",
    value: function addFont(path, data) {// let style = document.createElement("style"),name = Util.fileName(path);
      // style.innerText = `@font-face { font-family: '${name}'; src:url('${this.createImg(path,data)}') format('truetype'); } `;
      // document.head.appendChild(style);
      // style.onload = ()=>{
      // 	document.head.removeChild(style);
      // }
    }
  }]);

  return Browser;
}();
/****************** 立即执行 ******************/


_fs.default.createFs = function (cfg, callback) {
  _fs.default.fs = new Browser(cfg, callback);
};
})