define("libs/wx/api",function(require,exports,module){
"use strict";

var _emitter = _interopRequireDefault(require("libs/ni/emitter"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @description 微信分享
 * 所有分享走相同的流程，通过事件分发机制传递分享数据
 */

/****************** 导入 ******************/
var shareInfo = {
  //分享详情
  title: "",
  query: "",
  callback: function callback() {}
};
var RewardedVideoAd, // 激励广告组件
BannerAd, //banner广告组件
SDKVersion;
var sys = wx.getSystemInfoSync();
/**
 * @description 微信api调用状态
 */

var status = {
  /**
   * @description 分享状态
   * 0 没有分享
   * 1 正在分享
   */
  share: 0,

  /**
   * @description 手机震动状态
   * 0 没有震动
   * 1 震动结束
   */
  vibrate: 0
};
var launchOptions = wx.getLaunchOptionsSync();

var createShareInfo = function createShareInfo() {
  var wxinfo = wx.getSystemInfoSync();
  return {
    title: shareInfo.title,
    query: shareInfo.query,
    imageUrl: canvas.toTempFilePathSync({
      destWidth: wxinfo.windowWidth,
      destHeight: wxinfo.windowHeight
    })
  };
};

var caclVersion = function caclVersion() {
  var arr = sys.SDKVersion.split();

  for (var i = 0, len = arr.length; i < len; i++) {
    if (arr[i].length == 1) {
      arr[i] += "0";
    }
  }

  SDKVersion = parseInt(arr.join(""), 10);
};
/**
 * @description 创建激励广告
 * @callback (errcode) 0: 广告有效 1: 基础库太低，无法加载激励广告 2: 无效观看 3: 微信api调用错误
 */


var createRewardedVideoAd = function createRewardedVideoAd(id, callback) {
  if (SDKVersion < 200040) {
    callback(1);
  }

  var RewardedVideoAd = wx.createRewardedVideoAd({
    adUnitId: id
  }),
      destroy = function destroy() {
    RewardedVideoAd.destroy();
    RewardedVideoAd = undefined;
  };

  RewardedVideoAd.load();
  RewardedVideoAd.show();
  RewardedVideoAd.onError(function (err) {
    console.log(err);
    destroy();
    callback(3);
  });
  RewardedVideoAd.onClose(function (res) {
    // 用户点击了【关闭广告】按钮
    // 小于 2.1.0 的基础库版本，res 是一个 undefined
    destroy();

    if (res && res.isEnded || res === undefined) {
      callback(0);
    } else {
      callback(2);
    }
  });
};
/**
 * @description 创建banner广告
 * @callback (banner) banner组件实例，用于销毁组件(banner.destroy())
 */


var createBannerAd = function createBannerAd(id, callback) {
  if (SDKVersion < 200040) {
    callback();
  }

  var BannerAd = wx.createBannerAd({
    adUnitId: id,
    adIntervals: 30,
    style: {
      width: sys.windowWidth,
      left: 0
    }
  });
  BannerAd.onResize(function (res) {
    BannerAd.style.top = sys.windowHeight - res.height;
  });
  callback(BannerAd);
};
/****************** 立即执行 ******************/


caclVersion();
wx.showShareMenu({
  withShareTicket: true,
  success: function success() {// console.log("open share success!")
  },
  fail: function fail() {// console.log("open share fail!")
  },
  complete: function complete() {// console.log("open share complete!")
  }
});
/**
 * @description 被动分享监听
 */

wx.onShareAppMessage(function () {
  status.share = 1;
  return createShareInfo();
});
wx.onShow(function (res) {
  // console.log("show::",res);
  _emitter.default.global.emit("show");
  /**
   * @description 分享成功
   */


  if (status.share == 1) {
    shareInfo.callback && shareInfo.callback();
    shareInfo.callback = null;
    status.share = 0;
  }
});
wx.onHide(function (res) {
  // console.log("hide::",res);
  _emitter.default.global.emit("hide");
}); //初始化
// Emitter.global.add("intoMain",()=>{
//     console.log(launchOptions);
// })
//========= 外部接口 ========\\

/**
 * @description 主动分享
 */

_emitter.default.global.add("share", function (arg) {
  status.share = 1;
  wx.shareAppMessage(createShareInfo());
});
/**
 * @description 设置分享信息
 */


_emitter.default.global.add("setShareInfo", function (arg) {
  shareInfo = arg;
});
/**
 * @description 手机震动
 */


_emitter.default.global.add("vibrate", function () {
  status.vibrate = 1; // let t = Date.now();

  wx.vibrateShort({
    success: function success() {// console.log(`vibrate time = ${Date.now() - t}`);
    },
    fail: function fail() {},
    complete: function complete() {// console.log(`vibrate time = ${Date.now() - t}`);
    }
  });
});
/**
 * @description 打开激励广告
 * @param arg {
 *      id: ADVID, //广告id
        callback
 * }
 */


_emitter.default.global.add("advRewarded", function (arg) {
  createRewardedVideoAd(arg.id, arg.callback);
});
/**
 * @description 打开banner广告
 * @callback (banner) banner组件实例，用于销毁组件(banner.destroy())
 */


_emitter.default.global.add("advBanner", function (arg) {
  createBannerAd(arg.id, arg.callback);
});
})